#!/bin/sh

basedir=`pwd`

user=tipadmin
passwd=tippass
if [ ! -z "$1" ]; then
	user=$1
fi
if [ ! -z "$2" ]; then
	passwd=$2
fi
ifix="7303-0001"
full="7.3.0.3"

echo "Searching for installed components..."

de=""
for dir in $SI_PATH/bin $HOME/.acsi_$USER/bin /usr/ibm/common/acsi/bin
do
	if [ -x $dir/de_lsrootiu.sh ]; then
		de=$dir
		break
	fi
done
if [ -z "$de" ]; then
	echo "Unable to find DE"
	exit 1
fi

patched=0
$de/de_lsrootiu.sh | grep "IU,TUAM_" | sort | (while read line
do
	oifs="$IFS"
	IFS=","
	set `echo "$line" | awk -F, '{print $2 "," $4 "," $5 "," $6}' | sed 's/]<.*//'`
	IFS="$oifs"
	component=$1
	version=$2
	disc=$3
	uuid=$4
	installedbase=`echo $version | awk -F. '{print $1 "." $2 "." $3}'`
	installedfp=`echo $version | awk -F. '{print $NF}'`
	if [ "$version" == "$full" ] && [ -d $basedir/${component}-${ifix}/META-INF ] && [ ! -d $TUAM_HOME/_uninst/fixes/ifix${ifix}/$component ]; then
		echo "Applying patch for $component"
		cd $basedir/${component}-${ifix}/META-INF
		. $disc/bin/setupEnv.sh
		if [ "$component" == "TUAM_UI" ]; then
			cat > var.properties <<EOF
Variable#RootIUTypeID[${uuid},${component}-${ifix}]#IAGLOBAL_TIP_HOME=${TIP_HOME}
Variable#RootIUTypeID[${uuid},${component}-${ifix}]#shExt=sh
Variable#RootIUTypeID[${uuid},${component}-${ifix}]#IAGLOBAL_WASUserID=$user
Variable#RootIUTypeID[${uuid},${component}-${ifix}]#IALOCAL_WASPassword=$passwd
EOF
			$de/manageIU.sh -o update -u true -i var.properties -r $TUAM_HOME -p packagedIU.xml >> $TUAM_HOME/logs/ifix_${component}-${ifix}.log 2>&1
			status=$?
			rm -f var.properties
		else
			$de/manageIU.sh -o update -r $TUAM_HOME -p packagedIU.xml -u true >> $TUAM_HOME/logs/ifix_${component}-${ifix}.log 2>&1
			status=$?
		fi
		if [ $status -ne 0 ]; then
			echo "Patch failed"
			exit 1
		fi
		mkdir -p $TUAM_HOME/_uninst/fixes/ifix${ifix}/$component
		cp * $TUAM_HOME/_uninst/fixes/ifix${ifix}/$component
		patched=1
	fi
done
if [ $patched -eq 0 ]; then
   echo "TUAM Release ${full} must be installed to install this interim fix."
   echo "Please install this version before attempting to install this fix."
   echo "Fix has not been applied successfully."
   exit 1
fi
)

