#!/bin/sh

basedir=`pwd`

user=tipadmin
passwd=tippass
if [ ! -z "$1" ]; then
	user=$1
fi
if [ ! -z "$2" ]; then
	passwd=$2
fi
ifix="7303-0001"
full="7.3.0.3"

echo "Searching for installed components..."

de=""
for dir in $SI_PATH/bin $HOME/.acsi_$USER/bin /usr/ibm/common/acsi/bin
do
	if [ -x $dir/de_lsrootiu.sh ]; then
		de=$dir
		break
	fi
done
if [ -z "$de" ]; then
	echo "Unable to find DE"
	exit 1
fi

patched=0
$de/de_lsrootiu.sh | grep "IU,TUAM_" | sort | (while read line
do
	oifs="$IFS"
    IFS=","
	set `echo "$line" | awk -F, '{print $2 "," $4 "," $5 "," $6}' | sed 's/]<.*//'`
	IFS="$oifs"
	component=$1
	version=$2
	disc=$3
	uuid=$4
	[ -x $disc/bin/setupEnv.sh ] && . $disc/bin/setupEnv.sh
	if [ "$version" == "${full}" ] && [ -d $TUAM_HOME/_uninst/fixes/ifix${ifix}/$component ]; then
		echo "Undoing patch for $component"
		cd $TUAM_HOME/_uninst/fixes/ifix${ifix}/$component
		if [ "$component" == "TUAM_UI" ]; then
			cat > var.properties <<EOF
Variable#RootIUTypeID[${uuid},${component}-${ifix}]#IAGLOBAL_TIP_HOME=${TIP_HOME}
Variable#RootIUTypeID[${uuid},${component}-${ifix}]#shExt=sh
EOF
			$de/manageIU.sh -o undo -i var.properties -r $TUAM_HOME -p packagedIU.xml >> $TUAM_HOME/logs/ifix_${component}-${ifix}.log 2>&1
			status=$?
			rm -f var.properties
		else
			$de/manageIU.sh -o undo -r $TUAM_HOME -p packagedIU.xml >> $TUAM_HOME/logs/ifix_${component}-${ifix}.log 2>&1
			status=$?
		fi
		if [ $status -ne 0 ]; then
			echo "Undo failed"
			exit 1
		else
			rm -rf $TUAM_HOME/_uninst/fixes/ifix${ifix}/$component
		fi
		patched=1
	fi
done
if [ $patched -eq 0 ]; then
   echo "TUAM IFIX ${ifix} must be installed to remove this interim fix."
   echo "Please install this version before attempting to remove this fix."
   echo "Fix has not been unapplied successfully."
   exit 1
fi
)
